==> haskell-language-python-0.5.8-171-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-language-python.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 language-python
version:              0.5.8
visibility:           public
id:                   language-python-0.5.8-EJ40YBLIDss3GmwJFQRIZH
key:                  language-python-0.5.8-EJ40YBLIDss3GmwJFQRIZH
license:              BSD-3-Clause
copyright:            (c) 2008-2019 Bernard James Pope
maintainer:           florbitous@gmail.com
author:               Bernard James Pope (Bernie Pope)
stability:            experimental
homepage:             http://github.com/bjpop/language-python 
synopsis:             Parsing and pretty printing of Python code. 
description:
    language-python is a Haskell library for lexical analysis, parsing
    and pretty printing Python code. It supports versions 2.x and 3.x of Python.

category:             Language
abi:                  011aee544662c20d95c90e136f828abd
exposed:              True
exposed-modules:
    Language.Python.Common Language.Python.Common.AST
    Language.Python.Common.ParseError
    Language.Python.Common.ParserMonad Language.Python.Common.Pretty
    Language.Python.Common.PrettyAST
    Language.Python.Common.PrettyParseError
    Language.Python.Common.PrettyToken
    Language.Python.Common.SrcLocation
    Language.Python.Common.StringEscape Language.Python.Common.Token
    Language.Python.Version2 Language.Python.Version2.Lexer
    Language.Python.Version2.Parser Language.Python.Version3
    Language.Python.Version3.Lexer Language.Python.Version3.Parser

hidden-modules:
    Language.Python.Common.ParserUtils
    Language.Python.Common.LexerUtils
    Language.Python.Version3.Parser.Parser
    Language.Python.Version3.Parser.Lexer
    Language.Python.Version2.Parser.Parser
    Language.Python.Version2.Parser.Lexer

import-dirs:          /usr/lib/ghc-9.4.8/site-local/language-python-0.5.8
library-dirs:         /usr/lib/ghc-9.4.8/site-local/language-python-0.5.8
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/language-python-0.5.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-language-python
hs-libraries:         HSlanguage-python-0.5.8-EJ40YBLIDss3GmwJFQRIZH
depends:
    array-0.5.4.0 base-4.17.2.1 containers-0.6.7
    monads-tf-0.1.0.3-6sILdwn34pYGvOyy3w0bJb pretty-1.1.3.6
    transformers-0.5.6.2 utf8-string-1.0.2-7x3IoasPx5wHP6oJo1JvJP

haddock-interfaces:
    /usr/share/doc/haskell-language-python/html/language-python.haddock

haddock-html:         /usr/share/doc/haskell-language-python/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-language-python-0.5.8-180-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-language-python.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 language-python
version:              0.5.8
visibility:           public
id:                   language-python-0.5.8-3px2A25iF8EBC3UX4Bdb9x
key:                  language-python-0.5.8-3px2A25iF8EBC3UX4Bdb9x
license:              BSD-3-Clause
copyright:            (c) 2008-2019 Bernard James Pope
maintainer:           florbitous@gmail.com
author:               Bernard James Pope (Bernie Pope)
stability:            experimental
homepage:             http://github.com/bjpop/language-python 
synopsis:             Parsing and pretty printing of Python code. 
description:
    language-python is a Haskell library for lexical analysis, parsing
    and pretty printing Python code. It supports versions 2.x and 3.x of Python.

category:             Language
abi:                  c07dbf2b4bd6e215c59f79c283143fd4
exposed:              True
exposed-modules:
    Language.Python.Common Language.Python.Common.AST
    Language.Python.Common.ParseError
    Language.Python.Common.ParserMonad Language.Python.Common.Pretty
    Language.Python.Common.PrettyAST
    Language.Python.Common.PrettyParseError
    Language.Python.Common.PrettyToken
    Language.Python.Common.SrcLocation
    Language.Python.Common.StringEscape Language.Python.Common.Token
    Language.Python.Version2 Language.Python.Version2.Lexer
    Language.Python.Version2.Parser Language.Python.Version3
    Language.Python.Version3.Lexer Language.Python.Version3.Parser

hidden-modules:
    Language.Python.Common.ParserUtils
    Language.Python.Common.LexerUtils
    Language.Python.Version3.Parser.Parser
    Language.Python.Version3.Parser.Lexer
    Language.Python.Version2.Parser.Parser
    Language.Python.Version2.Parser.Lexer

import-dirs:          /usr/lib/ghc-9.4.8/site-local/language-python-0.5.8
library-dirs:         /usr/lib/ghc-9.4.8/site-local/language-python-0.5.8
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/language-python-0.5.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-language-python
hs-libraries:         HSlanguage-python-0.5.8-3px2A25iF8EBC3UX4Bdb9x
depends:
    array-0.5.4.0 base-4.17.2.1 containers-0.6.7
    monads-tf-0.1.0.3-6sILdwn34pYGvOyy3w0bJb pretty-1.1.3.6
    transformers-0.5.6.2 utf8-string-1.0.2-FnO1h94XkEn7naEuvLflUO

haddock-interfaces:
    /usr/share/doc/haskell-language-python/html/language-python.haddock

haddock-html:         /usr/share/doc/haskell-language-python/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
